@@ -1,7 +1,8 @@
 from typing import Any, List, Optional, cast, Union, overload, Sequence, Iterable
 
 from .functions import RemoteFunction
-from .hints import SkillCode, Symbol, Var
+from .hints import SkillCode, Symbol
+from .var import Var
 from .channel import Channel
 from .translator import Translator, snake_to_camel
 
